# Generated by Django 5.0.4 on 2024-04-22 08:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0010_alter_container_port"),
    ]

    operations = [
        migrations.AlterField(
            model_name="container",
            name="tailscale_serve_url",
            field=models.URLField(
                default="",
                help_text="Tailscale Serve URL to access this container's RStudio instance from the tailnet",
                max_length=1024,
                null=True,
            ),
        ),
    ]
