{% if cancel_url %}<a href="{{ cancel_url }}" class="float-right btn btn-link">Cancel</a>{% endif %}
{% if wizard.steps.prev %}
  <button name="wizard_goto_step"
          type="submit"
          value="{{ wizard.steps.prev }}"
          class="secondary">Back</button>
{% else %}
  <button disabled name="" type="button" class="secondary">Back</button>
{% endif %}
<button type="submit" class="btn btn-primary">Next</button>
