# Generated by Django 5.0.4 on 2024-04-24 10:26

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0013_remove_project_password_container_password"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="max_containers",
            field=models.PositiveIntegerField(
                default=4,
                help_text="Maximum number of containers that can be run for the project.",
            ),
        ),
    ]
