# Generated by Django 5.0.4 on 2024-07-01 08:27

import r_shepard.api.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0019_alter_project_commit_interval_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='container',
            name='port',
            field=models.PositiveIntegerField(default=8787, help_text="The host port on which the container's RStudio instance is accessible locally. Should only be used for testing as this won't be HTTPS enabled.", unique=True, validators=[r_shepard.api.models.validate_port], verbose_name='Host Port'),
        ),
    ]
